==> jc-1.4.0.tar.gz: javax/swing/border/TitledBorder__24Measurements.h <==
// class javax.swing.border.TitledBorder$Measurements

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 656eec5d9e08a6db javax_swing_border_TitledBorder__24Measurements

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_border_TitledBorder__24Measurements_H_
#define _JC_javax_swing_border_TitledBorder__24Measurements_H_

// Forward structure declarations
struct _jc_java_awt_Dimension$object;
struct _jc_java_awt_Font$object;
struct _jc_java_awt_Insets$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_swing_border_Border$object;
struct _jc_javax_swing_border_TitledBorder__242$object;

// Typedefs
typedef struct _jc_javax_swing_border_TitledBorder__24Measurements$sub_refs	_jc_javax_swing_border_TitledBorder__24Measurements$sub_refs;
typedef struct _jc_javax_swing_border_TitledBorder__24Measurements$sub_nonrefs	_jc_javax_swing_border_TitledBorder__24Measurements$sub_nonrefs;
typedef struct _jc_javax_swing_border_TitledBorder__24Measurements$refs	_jc_javax_swing_border_TitledBorder__24Measurements$refs;
typedef struct _jc_javax_swing_border_TitledBorder__24Measurements$nonrefs	_jc_javax_swing_border_TitledBorder__24Measurements$nonrefs;
typedef struct _jc_javax_swing_border_TitledBorder__24Measurements$object	_jc_javax_swing_border_TitledBorder__24Measurements$object;

typedef const struct _jc_javax_swing_border_TitledBorder__24Measurements$vmethods	_jc_javax_swing_border_TitledBorder__24Measurements$vmethods;
typedef const struct _jc_javax_swing_border_TitledBorder__24Measurements$vtable	_jc_javax_swing_border_TitledBorder__24Measurements$vtable;
typedef const struct _jc_javax_swing_border_TitledBorder__24Measurements$vtype	_jc_javax_swing_border_TitledBorder__24Measurements$vtype;

// Constructors
extern void _jc_javax_swing_border_TitledBorder__24Measurements$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_border_TitledBorder__24Measurements$object *);
extern void _jc_javax_swing_border_TitledBorder__24Measurements$method$_init$29b46820901e6b99(_jc_env *, struct _jc_javax_swing_border_TitledBorder__24Measurements$object *, struct _jc_javax_swing_border_TitledBorder__242$object *);

// Virtual methods
extern struct _jc_java_awt_Insets$object *_jc_javax_swing_border_TitledBorder__24Measurements$method$getContentInsets$47a736edc8370df2(_jc_env *, struct _jc_javax_swing_border_TitledBorder__24Measurements$object *, struct _jc_java_awt_Insets$object *);
extern struct _jc_java_awt_Dimension$object *_jc_javax_swing_border_TitledBorder__24Measurements$method$getMinimumSize$f439289f02165af0(_jc_env *, struct _jc_javax_swing_border_TitledBorder__24Measurements$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_border_TitledBorder__24Measurements$method_info$getContentInsets$47a736edc8370df2;
extern _jc_method _jc_javax_swing_border_TitledBorder__24Measurements$method_info$getMinimumSize$f439289f02165af0;

// Virtual methods structure
struct _jc_javax_swing_border_TitledBorder__24Measurements$vmethods {
	struct _jc_java_awt_Insets$object	*(*getContentInsets$47a736edc8370df2)(_jc_env *, struct _jc_javax_swing_border_TitledBorder__24Measurements$object *, struct _jc_java_awt_Insets$object *);
	struct _jc_java_awt_Dimension$object	*(*getMinimumSize$f439289f02165af0)(_jc_env *, struct _jc_javax_swing_border_TitledBorder__24Measurements$object *);
};

// Vtable
struct _jc_javax_swing_border_TitledBorder__24Measurements$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_border_TitledBorder__24Measurements$vmethods	javax_swing_border_TitledBorder__24Measurements;
};

// Vtype
struct _jc_javax_swing_border_TitledBorder__24Measurements$vtype {
	_jc_type			type;
	_jc_javax_swing_border_TitledBorder__24Measurements$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_border_TitledBorder__24Measurements$sub_refs {
	struct _jc_java_awt_Font$object	*font;
	struct _jc_java_lang_String$object	*trimmedText;
	struct _jc_object	*border;
	struct _jc_java_awt_Insets$object	*borderSpacing;
	struct _jc_java_awt_Insets$object	*borderInsets;
	struct _jc_java_awt_Insets$object	*edgeSpacing;
};

// Reference instance fields (object)
struct _jc_javax_swing_border_TitledBorder__24Measurements$refs {
    _jc_javax_swing_border_TitledBorder__24Measurements$sub_refs	javax_swing_border_TitledBorder__24Measurements;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_border_TitledBorder__24Measurements$sub_nonrefs {
	jint	textAscent;
	jint	textDescent;
	jint	textWidth;
};

// Non-reference instance fields (object)
struct _jc_javax_swing_border_TitledBorder__24Measurements$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_border_TitledBorder__24Measurements$sub_nonrefs	javax_swing_border_TitledBorder__24Measurements;
};

// Object instance structure
struct _jc_javax_swing_border_TitledBorder__24Measurements$object {
	_jc_javax_swing_border_TitledBorder__24Measurements$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_border_TitledBorder__24Measurements$vtype	*vtype;
	_jc_javax_swing_border_TitledBorder__24Measurements$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_border_TitledBorder__24Measurements$vtype _jc_javax_swing_border_TitledBorder__24Measurements$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_border_TitledBorder__24Measurements, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_border_TitledBorder__24Measurements$class_object;

#endif	/* _JC_javax_swing_border_TitledBorder__24Measurements_H_ */

==> jc-1.4.6.tar.gz: javax/swing/border/TitledBorder__24Measurements.h <==
// class javax.swing.border.TitledBorder$Measurements

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 656eec5d9e08a6db javax_swing_border_TitledBorder__24Measurements

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_border_TitledBorder__24Measurements_H_
#define _JC_javax_swing_border_TitledBorder__24Measurements_H_

// Forward structure declarations
struct _jc_java_awt_Dimension$object;
struct _jc_java_awt_Font$object;
struct _jc_java_awt_Insets$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_swing_border_Border$object;
struct _jc_javax_swing_border_TitledBorder__242$object;

// Typedefs
typedef struct _jc_javax_swing_border_TitledBorder__24Measurements$sub_refs	_jc_javax_swing_border_TitledBorder__24Measurements$sub_refs;
typedef struct _jc_javax_swing_border_TitledBorder__24Measurements$sub_nonrefs	_jc_javax_swing_border_TitledBorder__24Measurements$sub_nonrefs;
typedef struct _jc_javax_swing_border_TitledBorder__24Measurements$refs	_jc_javax_swing_border_TitledBorder__24Measurements$refs;
typedef struct _jc_javax_swing_border_TitledBorder__24Measurements$nonrefs	_jc_javax_swing_border_TitledBorder__24Measurements$nonrefs;
typedef struct _jc_javax_swing_border_TitledBorder__24Measurements$object	_jc_javax_swing_border_TitledBorder__24Measurements$object;

typedef const struct _jc_javax_swing_border_TitledBorder__24Measurements$vmethods	_jc_javax_swing_border_TitledBorder__24Measurements$vmethods;
typedef const struct _jc_javax_swing_border_TitledBorder__24Measurements$vtable	_jc_javax_swing_border_TitledBorder__24Measurements$vtable;
typedef const struct _jc_javax_swing_border_TitledBorder__24Measurements$vtype	_jc_javax_swing_border_TitledBorder__24Measurements$vtype;

// Constructors
extern void _jc_javax_swing_border_TitledBorder__24Measurements$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_border_TitledBorder__24Measurements$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_border_TitledBorder__24Measurements$method$_init$29b46820901e6b99(_jc_env *, struct _jc_javax_swing_border_TitledBorder__24Measurements$object *, struct _jc_javax_swing_border_TitledBorder__242$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_awt_Insets$object *_jc_javax_swing_border_TitledBorder__24Measurements$method$getContentInsets$47a736edc8370df2(_jc_env *, struct _jc_javax_swing_border_TitledBorder__24Measurements$object *, struct _jc_java_awt_Insets$object *) _JC_JCNI_ATTR;
extern struct _jc_java_awt_Dimension$object *_jc_javax_swing_border_TitledBorder__24Measurements$method$getMinimumSize$f439289f02165af0(_jc_env *, struct _jc_javax_swing_border_TitledBorder__24Measurements$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_border_TitledBorder__24Measurements$method_info$getContentInsets$47a736edc8370df2;
extern _jc_method _jc_javax_swing_border_TitledBorder__24Measurements$method_info$getMinimumSize$f439289f02165af0;

// Virtual methods structure
struct _jc_javax_swing_border_TitledBorder__24Measurements$vmethods {
	struct _jc_java_awt_Insets$object	*(*getContentInsets$47a736edc8370df2)(_jc_env *, struct _jc_javax_swing_border_TitledBorder__24Measurements$object *, struct _jc_java_awt_Insets$object *) _JC_JCNI_ATTR;
	struct _jc_java_awt_Dimension$object	*(*getMinimumSize$f439289f02165af0)(_jc_env *, struct _jc_javax_swing_border_TitledBorder__24Measurements$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_border_TitledBorder__24Measurements$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_border_TitledBorder__24Measurements$vmethods	javax_swing_border_TitledBorder__24Measurements;
};

// Vtype
struct _jc_javax_swing_border_TitledBorder__24Measurements$vtype {
	_jc_type			type;
	_jc_javax_swing_border_TitledBorder__24Measurements$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_border_TitledBorder__24Measurements$sub_refs {
	struct _jc_java_awt_Font$object	*font;
	struct _jc_java_lang_String$object	*trimmedText;
	struct _jc_object	*border;
	struct _jc_java_awt_Insets$object	*borderSpacing;
	struct _jc_java_awt_Insets$object	*borderInsets;
	struct _jc_java_awt_Insets$object	*edgeSpacing;
};

// Reference instance fields (object)
struct _jc_javax_swing_border_TitledBorder__24Measurements$refs {
    _jc_javax_swing_border_TitledBorder__24Measurements$sub_refs	javax_swing_border_TitledBorder__24Measurements;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_border_TitledBorder__24Measurements$sub_nonrefs {
	jint	textAscent;
	jint	textDescent;
	jint	textWidth;
};

// Non-reference instance fields (object)
struct _jc_javax_swing_border_TitledBorder__24Measurements$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_border_TitledBorder__24Measurements$sub_nonrefs	javax_swing_border_TitledBorder__24Measurements;
};

// Object instance structure
struct _jc_javax_swing_border_TitledBorder__24Measurements$object {
	_jc_javax_swing_border_TitledBorder__24Measurements$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_border_TitledBorder__24Measurements$vtype	*vtype;
	_jc_javax_swing_border_TitledBorder__24Measurements$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_border_TitledBorder__24Measurements$vtype _jc_javax_swing_border_TitledBorder__24Measurements$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_border_TitledBorder__24Measurements, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_border_TitledBorder__24Measurements$class_object;

#endif	/* _JC_javax_swing_border_TitledBorder__24Measurements_H_ */
